@@ -38,6 +38,8 @@ struct _SoupMessageQueueItem {
 	GMainContext *async_context;
 
 	GCancellable *cancellable;
+	GError *error;
+
 	SoupConnection *conn;
 	GTask *task;
 	GSource *io_source;
@@ -46,13 +48,14 @@ struct _SoupMessageQueueItem {
 	guint new_api           : 1;
 	guint io_started        : 1;
 	guint async             : 1;
-	guint resend_count      : 28;
+	guint priority          : 3;
+	guint resend_count      : 25;
 
 	SoupMessageQueueItemState state;
 
 	/*< private >*/
-	guint removed              : 1;
-	guint ref_count            : 31;
+	guint removed           : 1;
+	guint ref_count         : 31;
 	SoupMessageQueueItem *prev, *next;
 	SoupMessageQueueItem *related;
 };
